#ifndef NT2_INCLUDE_FUNCTIONS_SAFE_MIN_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SAFE_MIN_HPP_INCLUDED

#include <nt2/ieee/include/functions/safe_min.hpp>

#endif
